@@ -37,13 +37,13 @@ proc ::dialog_array::pdtk_array_listview_fillpage {arrayName} {
     set windowName [format ".%sArrayWindow" $arrayName]
     set topItem [expr [lindex [$windowName.lb yview] 0] * \
                      [$windowName.lb size]]
-    
+
     if {[winfo exists $windowName]} {
         set cmd "$::pd_array_listview_id($arrayName) \
                arrayviewlistfillpage \
                $::pd_array_listview_page($arrayName) \
                $topItem"
-        
+
         pdsend $cmd
     }
 }
@@ -76,7 +76,7 @@ proc ::dialog_array::pdtk_array_listview_new {id arrayName page} {
         "x11" {selection handle $windowName.lb \
                    "::dialog_array::listview_lbselection $arrayName"}
         "win32" {bind $windowName.lb <ButtonPress-3> \
-                     "::dialog_array::listview_popup $arrayName"} 
+                     "::dialog_array::listview_popup $arrayName"}
     }
     set $windowName.prevBtn [button $windowName.prevBtn -text "<-" \
                                  -command "::dialog_array::listview_changepage $arrayName -1"]
@@ -235,6 +235,7 @@ proc ::dialog_array::pdtk_array_dialog {mytoplevel name size flags newone} {
     if {[winfo exists $mytoplevel]} {
         wm deiconify $mytoplevel
         raise $mytoplevel
+        focus $mytoplevel
     } else {
         create_dialog $mytoplevel $newone
     }
@@ -316,18 +317,18 @@ proc ::dialog_array::create_dialog {mytoplevel newone} {
 
     # buttons
     frame $mytoplevel.buttonframe
-    pack $mytoplevel.buttonframe -side bottom -expand 1 -fill x -pady 2m
+    pack $mytoplevel.buttonframe -side bottom -pady 2m
     button $mytoplevel.buttonframe.cancel -text [_ "Cancel"] \
         -command "::dialog_array::cancel $mytoplevel"
-    pack $mytoplevel.buttonframe.cancel -side left -expand 1 -fill x -padx 10
+    pack $mytoplevel.buttonframe.cancel -side left -expand 1 -fill x -padx 15 -ipadx 10
     if {$newone == 0 && $::windowingsystem ne "aqua"} {
         button $mytoplevel.buttonframe.apply -text [_ "Apply"] \
             -command "::dialog_array::apply $mytoplevel"
-        pack $mytoplevel.buttonframe.apply -side left -expand 1 -fill x -padx 10
+        pack $mytoplevel.buttonframe.apply -side left -expand 1 -fill x -padx 15 -ipadx 10
     }
     button $mytoplevel.buttonframe.ok -text [_ "OK"]\
         -command "::dialog_array::ok $mytoplevel" -default active
-    pack $mytoplevel.buttonframe.ok -side left -expand 1 -fill x -padx 10
+    pack $mytoplevel.buttonframe.ok -side left -expand 1 -fill x -padx 15 -ipadx 10
 
     # live widget updates on OSX in lieu of Apply button
     if {$::windowingsystem eq "aqua"} {
@@ -353,28 +354,14 @@ proc ::dialog_array::create_dialog {mytoplevel newone} {
         # remove cancel button from focus list since it's not activated on Return
         $mytoplevel.buttonframe.cancel config -takefocus 0
 
-        # can't see focus for buttons, so disable it
-        $mytoplevel.array.saveme config -takefocus 0
-        $mytoplevel.drawas.points config -takefocus 0
-        $mytoplevel.drawas.polygon config -takefocus 0
-        $mytoplevel.drawas.bezier config -takefocus 0
-        if {[winfo exists $mytoplevel.options.radio0]} {
-            $mytoplevel.options.radio0 config -takefocus 0
-        }
-        if {[winfo exists $mytoplevel.options.radio1]} {
-            $mytoplevel.options.radio1 config -takefocus 0
-        }
-        if {[winfo exists $mytoplevel.options.deletearray]} {
-            $mytoplevel.options.deletearray config -takefocus 0
-        }
-        if {[winfo exists $mytoplevel.options.listview]} {
-            $mytoplevel.options.listview config -takefocus 0
-        }
-
         # show active focus on the ok button as it *is* activated on Return
         $mytoplevel.buttonframe.ok config -default normal
         bind $mytoplevel.buttonframe.ok <FocusIn> "$mytoplevel.buttonframe.ok config -default active"
         bind $mytoplevel.buttonframe.ok <FocusOut> "$mytoplevel.buttonframe.ok config -default normal"
+
+        # since we show the active focus, disable the highlight outline
+        $mytoplevel.buttonframe.ok config -highlightthickness 0
+        $mytoplevel.buttonframe.cancel config -highlightthickness 0
     }
 }
 
